# molog

logging, but more refined, typed and documented (fork of Python [1054a75](https://github.com/python/cpython/tree/1054a755a3016f95fcd24b3ad20e8ed9048b7939))


## Copyright

This package is a fork of Python [1054a75](https://github.com/python/cpython/tree/1054a755a3016f95fcd24b3ad20e8ed9048b7939)
